@@ -459,7 +459,7 @@ def create_handler(element, key, value, idmap):
     tmp = re.sub('([\'"][^\'"]*[\'"])', '', value)
 
     # detect key.value inside value
-    kw = re.findall('([a-zA-Z0-9_.]+\.[a-zA-Z0-9_.]+)', tmp)
+    kw = re.findall('([a-zA-Z_][a-zA-Z0-9_.]*\.[a-zA-Z0-9_.]+)', tmp)
     if not kw:
         # look like no reference, just pass it
         return eval(value, _eval_globals)
